@@ -6,6 +6,7 @@ import pytest
 
 from ..const import (
     TEST_ACCOUNT_ID,
+    TEST_LOCK_ID,
     TEST_SUBSCRIPTION_ID,
     TEST_SYSTEM_ID,
     TEST_SYSTEM_SERIAL_NO,
@@ -38,19 +39,19 @@ def v3_server(
     )
     server.add(
         "api.simplisafe.com",
-        "/v1/users/{0}/subscriptions".format(TEST_USER_ID),
+        f"/v1/users/{TEST_USER_ID}/subscriptions",
         "get",
         aresponses.Response(text=json.dumps(v3_subscriptions_json), status=200),
     )
     server.add(
         "api.simplisafe.com",
-        "/v1/ss3/subscriptions/{0}/sensors".format(TEST_SUBSCRIPTION_ID),
+        f"/v1/ss3/subscriptions/{TEST_SUBSCRIPTION_ID}/sensors",
         "get",
         aresponses.Response(text=json.dumps(v3_sensors_json), status=200),
     )
     server.add(
         "api.simplisafe.com",
-        "/v1/ss3/subscriptions/{0}/settings/pins".format(TEST_SUBSCRIPTION_ID),
+        f"/v1/ss3/subscriptions/{TEST_SUBSCRIPTION_ID}/settings/pins",
         "get",
         aresponses.Response(text=json.dumps(v3_settings_json), status=200),
     )
@@ -58,6 +59,18 @@ def v3_server(
     return server
 
 
+@pytest.fixture()
+def v3_lock_lock_response_json():
+    """Return a /v1/doorlock/<SUBSCRIPTION_ID>/<LOCK_ID>/state response from locking."""
+    return {"state": "lock"}
+
+
+@pytest.fixture()
+def v3_lock_unlock_response_json():
+    """Return a /v1/doorlock/<SUBSCRIPTION_ID>/<LOCK_ID>/state response from unlocking."""
+    return {"state": "unlock"}
+
+
 @pytest.fixture()
 def v3_sensors_json():
     """Return a /v1/ss3/subscriptions/<SUBSCRIPTION_ID>/sensors response."""
@@ -409,6 +422,50 @@ def v3_sensors_json():
                     "offline": False,
                 },
             },
+            {
+                "serial": TEST_LOCK_ID,
+                "type": 16,
+                "status": {
+                    "pinPadState": 0,
+                    "lockState": 1,
+                    "pinPadOffline": False,
+                    "pinPadLowBattery": False,
+                    "lockDisabled": False,
+                    "lockLowBattery": False,
+                    "calibrationErrDelta": 0,
+                    "calibrationErrZero": 0,
+                    "lockJamState": 0,
+                },
+                "name": "Front Door",
+                "deviceGroupID": 1,
+                "firmwareVersion": "1.0.0",
+                "bootVersion": "1.0.0",
+                "setting": {
+                    "autoLock": 3,
+                    "away": 1,
+                    "home": 1,
+                    "awayToOff": 0,
+                    "homeToOff": 1,
+                },
+                "flags": {
+                    "swingerShutdown": False,
+                    "lowBattery": False,
+                    "offline": False,
+                },
+            },
+            {
+                "serial": "654",
+                "type": 253,
+                "status": {},
+                "name": "Front Door",
+                "deviceGroupID": 1,
+                "setting": {},
+                "flags": {
+                    "swingerShutdown": False,
+                    "lowBattery": False,
+                    "offline": False,
+                },
+            },
         ],
         "lastUpdated": 1534626361,
         "lastSynced": 1534626361,
@@ -715,11 +772,16 @@ def v3_subscriptions_json():
                         "alarmStateTimestamp": 0,
                         "isAlarming": False,
                         "version": 3,
-                        "temperature": 67,
+                        "temperature": 61,
                         "exitDelayRemaining": 60,
                         "cameras": [],
-                        "stateUpdated": 1534625833,
+                        "connType": "wifi",
+                        "stateUpdated": 1573331519,
                         "messages": [],
+                        "powerOutage": False,
+                        "lastPowerOutage": 1570722271,
+                        "lastSuccessfulWifiTS": 1573246093,
+                        "isOffline": False,
                     },
                 },
                 "currency": "USD",
